@@ -175,6 +175,7 @@ CELERY_EAGER_PROPAGATES_EXCEPTIONS = False
 CELERY_ALWAYS_EAGER = True
 BROKER_BACKEND = 'memory'
 CELERY_DEFAULT_QUEUE = 'default'
-SECURITY_AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS = (
-    'check', 'create_user'
-)
+SECURITY_AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS = {
+    'check': {},
+    'create_user': {},
+}
