@@ -1,27 +1,27 @@
 import atexit
+import logging
 import re
 import sys
 import traceback
-import itertools
-from datetime import datetime, time, timedelta
+from contextlib import ContextDecorator
 from importlib import import_module
 from io import StringIO
 from threading import local
 
-from contextlib import ContextDecorator
-
 from django.conf import settings as django_settings
-from django.core.signals import request_finished
 from django.core.exceptions import ImproperlyConfigured
+from django.core.signals import request_finished
 from django.db.transaction import get_connection
 from django.urls import resolve
 from django.urls.exceptions import Resolver404
-from django.utils import timezone
 from django.utils.timezone import now
 
 from .config import settings
 
 
+output_logged_request_logger = logging.getLogger('security.output_request')
+
+
 class LogManagementError(Exception):
     pass
 
@@ -259,6 +259,21 @@ def log_output_request(data, related_objects=None):
     else:
         output_logged_request_context.create()
 
+    if settings.LOG_OUTPUT_REQUESTS:
+        output_logged_request_logger.info(
+            ('"{request_timestamp}" "{response_timestamp}" "{response_time}" "{http_code}" "{http_host}" "{http_path}" '
+             '"{http_method}" "{slug}"').format(
+                request_timestamp=data.get('request_timestamp', ''),
+                response_timestamp=data.get('response_timestamp', ''),
+                response_time=data.get('response_time', ''),
+                http_code=data.get('response_code', ''),
+                http_host=data.get('host', ''),
+                http_path=data.get('path', ''),
+                http_method=data.get('method', ''),
+                slug=data.get('slug', ''),
+            )
+        )
+
 
 def is_base_collection(v):
     return isinstance(v, (list, tuple, set))
